#include <boost/math/special_functions/lambert_w.hpp>
#include "../boostmath/macros.hpp"

UNARY_BOOST_FUNCTION(lambert_w0, double);
UNARY_BOOST_FUNCTION(lambert_wm1, double);
UNARY_BOOST_FUNCTION(lambert_w0_prime, double);
UNARY_BOOST_FUNCTION(lambert_wm1_prime, double);
